/*
 * Beyond Arduino 3 - 1 Button-LED.c
 *
 *	Nuts & Volts - Beyond Arduino #3
 *  --------------------------------
 *	Use a push-button on PB1 to activate an LED on PB0, 
 *  illustrating digital inputs
 *
 *  Author: Andrew Retallack
 *			www.crash-bang.com
 */ 

#include <avr/io.h>			//Standard support for AVR I/O registers


int main(void)
{

	DDRB |= (1<<DDB0);		//Set PB0 as output - same as pinMode(x, OUTPUT)
	DDRB &= ~(1<<DDB1);		//Set PB1 as input - same as pinMode(x, INPUT)
	PORTB |= (1<<PORTB1);	//Enable the Pullup resistor on PB1
	
    while(1)
    {

		//When reading the button value, remember the pullup resistor:
		//  PB1 will be HIGH when button is not pressed
		//  PB1 will be LOW when button is pressed

		if ( (PINB & (1<<PINB1)) == 0 )	//Check whether PB1 is LOW, using bit-masking  
		{
			//PB1 is LOW:  Therefore button IS pressed
			PORTB |= (1<<PORTB0);	//Set LED on
		}
		
		else
		{
			//PB1 is not LOW:  Therefore button NOT pressed
			PORTB &= ~(1<<PORTB0);	//Set LED off
		}
		
    }
}
